# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
Name:          janino
Version:       2.7.8
Release:       %mkrel 10
Group:         Development/Java
Summary:       An embedded Java compiler
License:       BSD
URL:           http://unkrig.de/w/Janino
Source0:       http://janino.net/download/%{name}-%{version}.zip
Source1:       http://repo1.maven.org/maven2/org/codehaus/%{name}/%{name}-parent/%{version}/%{name}-parent-%{version}.pom
Source2:       http://repo1.maven.org/maven2/org/codehaus/%{name}/commons-compiler/%{version}/commons-compiler-%{version}.pom
Source3:       http://repo1.maven.org/maven2/org/codehaus/%{name}/commons-compiler-jdk/%{version}/commons-compiler-jdk-%{version}.pom
Source4:       http://repo1.maven.org/maven2/org/codehaus/%{name}/%{name}/%{version}/%{name}-%{version}.pom
# removes the de.unkrig.commons.nullanalysis annotations
# http://unkrig.de/w/Unkrig.de
# https://svn.code.sf.net/p/loggifier/code/tags/loggifier_0.9.9.v20140430-1829/de.unkrig.commons.nullanalysis/
Patch0:        %{name}-2.7.8-remove-nullanalysis-annotations.patch

BuildRequires: maven-local
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.apache.ant:ant)
BuildRequires: mvn(org.apache.maven.plugins:maven-enforcer-plugin)
BuildRequires: mvn(org.codehaus:codehaus-parent:pom:)

BuildArch:     noarch

%description
Janino is a super-small, super-fast Java compiler. Not only can it compile
a set of source files to a set of class files like the JAVAC tool, but also
can it compile a Java expression, block, class body or source file in
memory, load the byte-code and execute it directly in the same JVM. Janino
is not intended to be a development tool, but an embedded compiler for
run-time compilation purposes, e.g. expression evaluators or "server pages"
engines like JSP.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q

find . -name "*.jar" -delete
find . -name "*.class" -delete

for m in commons-compiler \
  commons-compiler-jdk \
  %{name};do
  mkdir -p ${m}/src
  (
    cd ${m}/src/
    unzip -qq  ../../${m}-src.zip
    if [ -f org.codehaus.commons.compiler.properties ]; then
      mkdir -p main/resources
      mv org.codehaus.commons.compiler.properties main/resources
    fi
  )
done

%patch0 -p1

install -m 644 %{SOURCE1} pom.xml
install -m 644 %{SOURCE2} commons-compiler/pom.xml
install -m 644 %{SOURCE3} commons-compiler-jdk/pom.xml
install -m 644 %{SOURCE4} %{name}/pom.xml

%pom_change_dep -r :ant-nodeps :ant

# RHBZ#842604
%pom_xpath_set "pom:plugin[pom:artifactId = 'maven-compiler-plugin']/pom:configuration/pom:source" 1.6
%pom_xpath_set "pom:plugin[pom:artifactId = 'maven-compiler-plugin']/pom:configuration/pom:target" 1.6

perl -pi -e 's/\r$//g' new_bsd_license.txt README.txt

# Cannot run program "svn"
%pom_remove_plugin :buildnumber-maven-plugin

%pom_remove_plugin :maven-clean-plugin
%pom_remove_plugin :maven-deploy-plugin
%pom_remove_plugin :maven-site-plugin
%pom_remove_plugin :maven-source-plugin

%build

%mvn_build

%install
%mvn_install

%files -f .mfiles
%doc README.txt
%license new_bsd_license.txt

%files javadoc -f .mfiles-javadoc
%license new_bsd_license.txt




%changelog
* Fri Feb 14 2020 umeabot <umeabot> 2.7.8-10.mga8
+ Revision: 1521061
- Mageia 8 Mass Rebuild

* Sun Dec 16 2018 daviddavid <daviddavid> 2.7.8-9.mga7
+ Revision: 1341636
- rebuild against current java stack

* Tue Sep 18 2018 umeabot <umeabot> 2.7.8-8.mga7
+ Revision: 1263310
- Mageia 7 Mass Rebuild

* Wed Mar 02 2016 neoclust <neoclust> 2.7.8-7.mga6
+ Revision: 982188
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 2.7.8-6.mga6
+ Revision: 976529
- First rebuild of the java stack
- sync package janino with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Dec 25 2014 pterjan <pterjan> 2.6.1-9.mga5
+ Revision: 805662
- Clean rebuild
- Sync with Fedora 21
- Restore
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 2.6.1-7.mga5
+ Revision: 742405
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Mon Dec 16 2013 dmorgan <dmorgan> 2.6.1-5.mga4
+ Revision: 557531
- Build with xmvn
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2.6.1-3.mga3
+ Revision: 354740
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 12 2012 dmorgan <dmorgan> 2.6.1-2.mga3
+ Revision: 292952
- Rebuilt RHBZ #842604 (compile with -target 1.5 or greater)

* Wed Jun 20 2012 dmorgan <dmorgan> 2.6.1-1.mga3
+ Revision: 262191
- New version 2.6.1

* Thu Oct 27 2011 gil <gil> 2.5.16-1.mga2
+ Revision: 158838
- update to 1.5.16

* Fri Jun 10 2011 gil <gil> 2.5.15-0.mga2
+ Revision: 102822
- imported package janino

